export declare const builtInDefaults: DefaultOptions;
/**
 * Depth of Field Lens object which can be used to calculate the depth of field at various distances
 *
 * @param  focalLength  Actual local length in millimeters (not the 35mm-equivalent)
 * @param  aperture     Aperture as a string in the format "f/2.5"
 * @param  cropFactor   Sensor crop factor
 * @param  id           Optional, arbitrary ID for tracking by the consumer
 */
export declare class Lens {
    readonly focalLength: Settings['focalLength'];
    readonly aperture: Settings['aperture'];
    readonly cropFactor: Settings['cropFactor'];
    readonly id: Settings['id'] | undefined;
    constructor({ focalLength, aperture, cropFactor, id }?: Options, customDefaults?: Options);
    /**
     * Determines the depth of field for the lens at the given distance
     *
     * @param distance Distance to the subject, in meters
     * @param imperialUnits Whether to use imperial units (feet) instead of metric
     */
    dof(distance?: number, imperialUnits?: boolean): {
        dof: number;
        focalLengthEquiv: number;
        eighthDof: number;
        hf: number;
        near: number;
        far: number;
        coc: number;
        toString: () => string;
    };
}
//# sourceMappingURL=Lens.d.ts.map