"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Lens_1 = require("../Lens");
const aperture_1 = require("./aperture");
const defaultOptionsAperture = Lens_1.builtInDefaults.aperture;
const defaultOptionsApertureNumber = Number(Lens_1.builtInDefaults.aperture.replace('f/', ''));
const customSettingsApertures = [undefined /* , 2.4, 'f/3.4' */];
describe.each(customSettingsApertures)('toActualAperture', (customSettingsAperture) => {
    describe(`customSettingsAperture: ${customSettingsAperture}`, () => {
        if (customSettingsAperture) {
            test('invalid string format is ignored and replaced with the custom value', () => {
                const expectedValue = customSettingsAperture === 2.4
                    ? 2.378414
                    : customSettingsAperture === 'f/3.4'
                        ? 3.363586
                        : undefined;
                // Verify the test setup
                expect(expectedValue).not.toBeUndefined();
                // Run the test
                expect((0, aperture_1.toActualAperture)({ input: 'ff//2', customSettingsAperture, defaultOptionsAperture })).toBe(expectedValue);
            });
        }
        else {
            test('invalid string format is ignored and replaced with the default value', () => {
                expect((0, aperture_1.toActualAperture)({ input: 'ff//2', customSettingsAperture, defaultOptionsAperture })).toBe(defaultOptionsApertureNumber);
            });
            test('a normal-looking value that is undocumented will be replaced with the default', () => {
                expect((0, aperture_1.toActualAperture)({ input: 'f/3.57', customSettingsAperture, defaultOptionsAperture })).toBe(2);
            });
        }
        test('undefined input value is replaced with the default value', () => {
            expect((0, aperture_1.toActualAperture)({ defaultOptionsAperture })).toBe(2);
            expect((0, aperture_1.toActualAperture)({ customSettingsAperture: 2.4, defaultOptionsAperture })).toBe(2.378414);
            expect((0, aperture_1.toActualAperture)({ customSettingsAperture: 'f/3.6', defaultOptionsAperture })).toBe(3.563595);
        });
        test('normal value, integer', () => {
            expect((0, aperture_1.toActualAperture)({ input: 'f/2', customSettingsAperture, defaultOptionsAperture })).toBe(2);
            expect((0, aperture_1.toActualAperture)({ input: 2, customSettingsAperture, defaultOptionsAperture })).toBe(2);
        });
        test('normal value, float', () => {
            expect((0, aperture_1.toActualAperture)({ input: 'f/3.4', customSettingsAperture, defaultOptionsAperture })).toBe(3.363586);
        });
        test('smaller than any value in our aperture map', () => {
            expect((0, aperture_1.toActualAperture)({ input: 'f/0.95', customSettingsAperture, defaultOptionsAperture })).toBe(0.95);
            expect((0, aperture_1.toActualAperture)({ input: 0.75, customSettingsAperture, defaultOptionsAperture })).toBe(0.75);
        });
        test('larger than any value in our aperture map', () => {
            expect((0, aperture_1.toActualAperture)({ input: 'f/128', customSettingsAperture, defaultOptionsAperture })).toBe(128);
            expect((0, aperture_1.toActualAperture)({ input: 205, customSettingsAperture, defaultOptionsAperture })).toBe(205);
        });
    });
});
//# sourceMappingURL=aperture.test.js.map